@@ -3,13 +3,23 @@ REST Wrapper for signal-cli running w/ JSON RPC
 """
 
 
+import os
 from sanic import Sanic
 
 from python_signal_cli_rest_api.api import entrypoint
 from python_signal_cli_rest_api.version import __version__
 
+dirname = os.path.dirname(os.path.realpath(__file__))
 app = Sanic("python-signal-cli-rest-api", env_prefix="PYTHON_SIGNAL_CLI_REST_API_")
+app.static(
+    "/openapi/assets/swagger",
+    f"{dirname}/openapi/assets/swagger",
+    name="swagger-assets",
+)
 app.config.FALLBACK_ERROR_FORMAT = "json"
+app.config.OAS_UI_DEFAULT = "swagger"
+app.config.OAS_UI_REDOC = False
+app.config.OAS_PATH_TO_SWAGGER_HTML = f"{dirname}/openapi/assets/swagger/swagger.html"
 app.config.API_HOST = (
     f'{app.config.get("API_HOST", "127.0.0.1")}:{app.config.get("API_PORT", 8080)}'
 )
